@@ -13,23 +13,14 @@
 
 #include <QMainWindow>
 #include <QLabel>
-#include <QLineEdit>
 #include <QComboBox>
 #include <QPushButton>
 #include <QProgressBar>
 #include <QStackedWidget>
 #include <KPixmapSequenceOverlayPainter>
 
-#if defined(Q_OS_LINUX)
-#include <kauth_version.h>
-#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
-#include <KAuth/ExecuteJob>
-#else
-#include <KAuth>
-#endif
-#endif
-
 class FetchIsoJob;
+class IsoLineEdit;
 
 class MainWindow : public QMainWindow
 {
@@ -51,7 +42,7 @@ private:
     QLabel *m_busyLabel;
     QWidget *m_busyWidget;
     QLabel *m_isoImageSizeLabel;
-    QLineEdit *m_isoImageLineEdit;
+    IsoLineEdit *m_isoImageLineEdit;
     QComboBox *m_usbDriveComboBox;
     QPushButton *m_createButton;
     QPushButton *m_cancelButton;
@@ -67,10 +58,6 @@ private:
     bool m_enumFlashDevicesWaiting;
     ExternalProgressBar m_externalProgressBar;
 
-#if defined(Q_OS_LINUX)
-    KAuth::ExecuteJob *m_job;
-#endif
-
     void setupUi();
     QWidget* createFormWidget();
     QWidget* createConfirmWidget();
@@ -98,14 +85,6 @@ private slots:
     void showConfirmMessage();
     void showIsoVerificationResult(IsoVerifier::VerifyResult result, const QString &error);
     void openUrl(const QUrl &url);
-
-#if defined(Q_OS_LINUX)
-    void cancelWriting();
-    void progressPercentUpdate(KJob* job, unsigned long percent);
-    void progressStep(const QVariantMap &);
-    void statusChanged(KAuth::Action::AuthStatus status);
-    void finished(KJob* job);
-#endif
 };
 
 #endif // MAINWINDOW_H
